import { context, trace } from '@opentelemetry/api';
import { ZoneContextManager } from '@opentelemetry/context-zone';
import { W3CTraceContextPropagator } from '@opentelemetry/core';
import { registerInstrumentations } from '@opentelemetry/instrumentation';
import { Resource } from '@opentelemetry/resources';
import { BatchSpanProcessor } from '@opentelemetry/sdk-trace-base';
import { WebTracerProvider } from '@opentelemetry/sdk-trace-web';
import { SemanticResourceAttributes } from '@opentelemetry/semantic-conventions';
import { agent, BaseInstrumentation, VERSION } from '@grafana/agent-core';
import { GrafanaAgentTraceExporter } from './agentExporter';
import { getDefaultOTELInstrumentations } from './getDefaultOTELInstrumentations';
import { GrafanaAgentSessionSpanProcessor } from './sessionSpanProcessor';
// the providing of app name here is not great
// should delay initialization and provide the full agent config,
// taking app name from it
export class TracingInstrumentation extends BaseInstrumentation {
    constructor(options = {}) {
        super();
        this.options = options;
        this.name = '@grafana/agent-tracing-web';
        this.version = VERSION;
    }
    initialize() {
        var _a, _b, _c, _d;
        const config = this.agent.config;
        const options = this.options;
        const attributes = {};
        if (config.app.name) {
            attributes[SemanticResourceAttributes.SERVICE_NAME] = config.app.name;
        }
        if (config.app.version) {
            attributes[SemanticResourceAttributes.SERVICE_VERSION] = config.app.version;
        }
        Object.assign(attributes, options.resourceAttributes);
        const resource = Resource.default().merge(new Resource(attributes));
        const provider = new WebTracerProvider({ resource });
        provider.addSpanProcessor((_a = options.spanProcessor) !== null && _a !== void 0 ? _a : new GrafanaAgentSessionSpanProcessor(new BatchSpanProcessor(new GrafanaAgentTraceExporter({ agent }), {
            scheduledDelayMillis: TracingInstrumentation.SCHEDULED_BATCH_DELAY_MS,
            maxExportBatchSize: 30,
        })));
        provider.register({
            propagator: (_b = options.propagator) !== null && _b !== void 0 ? _b : new W3CTraceContextPropagator(),
            contextManager: (_c = options.contextManager) !== null && _c !== void 0 ? _c : new ZoneContextManager(),
        });
        registerInstrumentations({
            instrumentations: (_d = options.instrumentations) !== null && _d !== void 0 ? _d : getDefaultOTELInstrumentations(this.getIgnoreUrls()),
        });
        agent.api.initOTEL(trace, context);
    }
    getIgnoreUrls() {
        return this.agent.transports.transports.flatMap((transport) => transport.getIgnoreUrls());
    }
}
TracingInstrumentation.SCHEDULED_BATCH_DELAY_MS = 1000;
//# sourceMappingURL=instrumentation.js.map